==> shell-0.1.0-sources.jar: io/github/qsy7/remote/plugins/shell/ServiceMessageHandlerService.java <==
package io.github.qsy7.remote.plugins.shell;

// import io.github.qsy7.queuedJob.api.model.JobExecution;
// import io.github.qsy7.queue.api.queuedJob.CallableJob;

import io.github.qsy7.remote.api.service.MessageWriterService;
import io.github.qsy7.remote.impl.handler.AbstractMessageHandler;
import io.github.qsy7.shell.api.service.ShellExecutionService;
import javax.inject.Inject;

public class ServiceMessageHandlerService extends AbstractMessageHandler
/*implements CallableJob<ServiceMessage, Void>*/ {
  protected final ShellExecutionService shellExecutionService;

  //  protected JobExecution jobExecution;
  protected ServiceMessage serviceMessage;

  @Inject
  public ServiceMessageHandlerService(
      MessageWriterService messageWriterService, ShellExecutionService shellExecutionService) {
    super(messageWriterService);
    this.shellExecutionService = shellExecutionService;
  }

  protected String getArguments(final ServiceMessage serviceMessage) {
    return ("sudo service "
        + serviceMessage.getService().getName()
        + " "
        + serviceMessage.getServiceAction().getCommand());
  }

  //  @Override
  //  public void onSuccess() {}
  //
  //  @Override
  //  public void onError(Throwable thrown) {}
  //
  //  @Override
  //  public void setJobExecution(JobExecution jobExecution) {
  //    this.jobExecution = jobExecution;
  //  }
  //
  //  @Override
  //  public void setEntity(ServiceMessage entity) {
  //    this.serviceMessage = entity;
  //  }
  //
  //  @Override
  //  public ServiceMessage getEntity() {
  //    return serviceMessage;
  //  }
  //
  //  @Override
  //  public Void call() throws Exception {
  //    ShellCommand shellCommand =
  //        new ShellCommand().withCommandLine(getArguments(serviceMessage)).withTimeout(10);
  //    shellExecutionService.run(shellCommand);
  //
  //    return null;
  //  }
}

==> shell-0.3.1-sources.jar: io/github/qsy7/remote/plugins/shell/ServiceMessageHandlerService.java <==
package io.github.qsy7.remote.plugins.shell;

// import io.github.qsy7.queuedJob.api.model.JobExecution;
// import io.github.qsy7.queue.api.queuedJob.CallableJob;

import io.github.qsy7.remote.api.service.MessageWriterService;
import io.github.qsy7.remote.impl.handler.AbstractMessageHandler;
import io.github.qsy7.shell.api.service.ShellExecutionService;
import jakarta.inject.Inject;

public class ServiceMessageHandlerService extends AbstractMessageHandler
/*implements CallableJob<ServiceMessage, Void>*/ {
  protected final ShellExecutionService shellExecutionService;

  //  protected JobExecution jobExecution;
  protected ServiceMessage serviceMessage;

  @Inject
  public ServiceMessageHandlerService(
      MessageWriterService messageWriterService, ShellExecutionService shellExecutionService) {
    super(messageWriterService);
    this.shellExecutionService = shellExecutionService;
  }

  protected String getArguments(final ServiceMessage serviceMessage) {
    return ("sudo service "
        + serviceMessage.getService().getName()
        + " "
        + serviceMessage.getServiceAction().getCommand());
  }

  //  @Override
  //  public void onSuccess() {}
  //
  //  @Override
  //  public void onError(Throwable thrown) {}
  //
  //  @Override
  //  public void setJobExecution(JobExecution jobExecution) {
  //    this.jobExecution = jobExecution;
  //  }
  //
  //  @Override
  //  public void setEntity(ServiceMessage entity) {
  //    this.serviceMessage = entity;
  //  }
  //
  //  @Override
  //  public ServiceMessage getEntity() {
  //    return serviceMessage;
  //  }
  //
  //  @Override
  //  public Void call() throws Exception {
  //    ShellCommand shellCommand =
  //        new ShellCommand().withCommandLine(getArguments(serviceMessage)).withTimeout(10);
  //    shellExecutionService.run(shellCommand);
  //
  //    return null;
  //  }
}
